@@ -3,7 +3,6 @@
 ## dummy stub for https://github.com/JuliaBinaryWrappers/nghttp2_jll.jl
 baremodule nghttp2_jll
 using Base, Libdl
-Base.Experimental.@compiler_options compile=min optimize=0 infer=false
 
 const PATH_list = String[]
 const LIBPATH_list = String[]
@@ -11,11 +10,11 @@ const LIBPATH_list = String[]
 export libnghttp2
 
 # These get calculated in __init__()
-PATH = Ref("")
-LIBPATH = Ref("")
-artifact_dir = ""
-libnghttp2_handle = C_NULL
-libnghttp2_path = ""
+const PATH = Ref("")
+const LIBPATH = Ref("")
+artifact_dir::String = ""
+libnghttp2_handle::Ptr{Cvoid} = C_NULL
+libnghttp2_path::String = ""
 
 if Sys.iswindows()
     const libnghttp2 = "libnghttp2-14.dll"
@@ -29,7 +28,7 @@ function __init__()
     global libnghttp2_handle = dlopen(libnghttp2)
     global libnghttp2_path = dlpath(libnghttp2_handle)
     global artifact_dir = dirname(Sys.BINDIR)
-    global LIBPATH[] = dirname(libnghttp2_path)
+    LIBPATH[] = dirname(libnghttp2_path)
     push!(LIBPATH_list, LIBPATH[])
 end
 
